@@ -1,5 +1,8 @@
 # Copyright 2021 D4n13l3k00.
-# SPDX-License-Identifier: 	AGPL-3.0-or-later
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
+__author__ = 'D4n13l3k00'
+__version__ = '1.3'
 
 from aioify import aioify
 
